#ifndef HARKIO_HARKCONFIG_IMPULSERESPONSELISTFILE_HPP_
#define HARKIO_HARKCONFIG_IMPULSERESPONSELISTFILE_HPP_

#include <string>
#include <vector>
#include <glibmm/ustring.h>
#include <harkio2/Version.hpp>
#include <harkio2/defineitem.hpp>
#include <harkio2/FileType.hpp>
#include <harkio2/TypedFilename.hpp>
#include <harkio2/harkconfig/HarkConfigFile.hpp>
#include <harkio2/harkconfig/Source.hpp>
#include <harkio2/harkconfig/HarkConfigFileWriter.hpp>

/** @file ImpulseResponseListFile.hpp
 * @brief ImpulseResponseListFile class and subclasses definitions.
 */

namespace harkio2
{
namespace harkconfig
{

/** @brief Abstract impulse response list file.
 * This class represents a file which contains a list of impulse responses.
 * The file can be any version.
 */
class ImpulseResponseListFile : public HarkConfigFile
{
public:
    /** @brief Returns the file type identifier.
     * @return The file type identifier which this class represents.
     */
    virtual std::string GetId() const { return "ImpulseResponseListFile"; }
};

/** @brief Impulse response list file version 1.0.
 */
class ImpulseResponseListFile1_0 : public ImpulseResponseListFile
{
public:
    /** @brief Returns the file version.
     * @return The version which this class represents.
     */
    virtual harkio2::Version GetVersion() const { return Version(1, 0); }

    DEFINE_ITEM(sources, std::vector<harkio2::harkconfig::Source1>, Sources, const std::vector<harkio2::harkconfig::Source1>&)

    /// @brief Implementation of Writable interface.
    void Write(HarkConfigFileWriter& writer) const throw (harkio2::InvalidHarkFile)
    {
        writer.Write(*this);
    }

};

/** @brief Impulse response list file version 2.0.
 */
class ImpulseResponseListFile2_0 : public ImpulseResponseListFile
{
public:
    /** @brief Returns the file version.
     * @return The version which this class represents.
     */
    virtual harkio2::Version GetVersion() const { return Version(2, 0); }

    DEFINE_ITEM(numMic, unsigned int, NumMic, unsigned int)
    DEFINE_ITEM(sourceFileType, harkio2::FileType::Kind, SourceFileType, harkio2::FileType::Kind)
    DEFINE_ITEM(comment, Glib::ustring, Comment, const Glib::ustring&)
    DEFINE_ITEM(sources, std::vector<harkio2::harkconfig::Source2>, Sources, const std::vector<harkio2::harkconfig::Source2>&)

    /// @brief Implementation of Writable interface.
    void Write(HarkConfigFileWriter& writer) const throw (harkio2::InvalidHarkFile)
    {
        writer.Write(*this);
    }

};

}
}

#endif // HARKIO_HARKCONFIG_IMPULSERESPONSELISTFILE_HPP_

